@@ -19,10 +19,15 @@ END {
 
 $chip->check_id->get;
 
-$chip->active( 1 )->get;
+$chip->change_config(
+   OS   => 16,
+)->get;
 
 while(1) {
-   sleep 1;
+   $chip->oneshot->get;
+
    printf "Pressure: %.2f Pa   Temperature: %.3f C\n",
       $chip->read_pressure->get, $chip->read_temperature->get;
+
+   sleep 10;
 }
